Go Contacts API
===============

A contacts and groups API for `Vumi Go`_.

.. _Vumi Go: http://github.com/praekelt/vumi-go

|gocontacts-ci|_ |gocontacts-cover|_

.. |gocontacts-ci| image:: https://travis-ci.org/praekelt/go-contacts-api.png?branch=develop
.. _gocontacts-ci: https://travis-ci.org/praekelt/go-contacts-api

.. |gocontacts-cover| image:: https://coveralls.io/repos/praekelt/go-contacts-api/badge.png?branch=develop
.. _gocontacts-cover: https://coveralls.io/r/praekelt/go-contacts-api

You can contact the Vumi development team in the following ways:

* via *email* by joining the the `vumi-dev@googlegroups.com`_ mailing list
* on *irc* in *#vumi* on the `Freenode IRC network`_

.. _vumi-dev@googlegroups.com: https://groups.google.com/forum/?fromgroups#!forum/vumi-dev
.. _Freenode IRC network: https://webchat.freenode.net/?channels=#vumi

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.
